import ROOT, time, sys


# default
show_n = 2000

if len(sys.argv) > 1:
  if sys.argv[1] == "--script-help":
    print "Use: python ArcPlot.py [N]" 
    print "     Will plot a graph for the last N seconds, or 2000 seconds if N "
    print "     is not specified. Use N = 0 to plot all data."
    sys.exit(0)
  show_n = int(sys.argv[1])
  if show_n == 0:
    show_n = None

data = [
  "l2_hits",
  "l2_misses",
  "l2_write_bytes",
  "l2_size",
  "size"
  ]

ngraphs = len(data)

c = ROOT.TCanvas("c1", "ARC stats", 1250, 900)
c.Divide(1,ngraphs)

print "L2ARC stats - Press Control-C to write PDF and exit"
while True:
  datafile = open("/tmp/arcstats.txt").readlines() 
  if show_n:
    datasec = datafile[-show_n:]
  else:
    datasec = datafile

  n = len(datasec)
  graphs = [ROOT.TGraph(n) for x in xrange(0,ngraphs)]

  try:
    for i,line in enumerate(datasec): 
      di = [float(val.strip()) for val in line.strip("\t\n").split("\t")]
      for gr, data_item in zip(graphs, di):
        gr.SetPoint(i, i, data_item)

    for i,gr in enumerate(graphs):
      c.cd(i+1)
      gr.SetTitle(data[i]) 
      gr.Draw("AP")
      gr.GetXaxis().SetLabelSize(0.06)
      gr.GetXaxis().SetTitle("seconds")
      gr.GetXaxis().SetTitleSize(0.06)
      gr.GetXaxis().SetTitleOffset(0.6)
      gr.GetYaxis().SetLabelSize(0.08)

    c.Update()

    try:
      time.sleep(10)
    except KeyboardInterrupt:
      c.Print("l2arc_plots.pdf")
      break
  except ValueError:
    # in between awks
    print "bad format, skipping (no problem)"
    time.sleep(1)

